@@ -1153,7 +1153,7 @@ ms_ole_summary_set_time (MsOleSummary *si, MsOleSummaryPID id,
  **/
 void
 ms_ole_summary_set_boolean (MsOleSummary *si, MsOleSummaryPID id,
-			    gboolean bool)
+			    gboolean value)
 {
 	write_item_t *w;
 
@@ -1166,7 +1166,7 @@ ms_ole_summary_set_boolean (MsOleSummary *si, MsOleSummaryPID id,
 	w->len  = 6;
 
 	MS_OLE_SET_GUINT32 (w->data + 0, TYPE_BOOLEAN);
-	MS_OLE_SET_GUINT16 (w->data + 4, bool);
+	MS_OLE_SET_GUINT16 (w->data + 4, value);
 }
 
 
