@@ -7,12 +7,16 @@
  **/
 
 #include <stdio.h>
+
+/* BSDs require unistd.h before including stat.h */
+#ifdef HAVE_UNISTD_H
 #include <unistd.h>
-#include <sys/mman.h>
-#include <sys/stat.h>	/* for struct stat */
+#endif
+
 #include <sys/types.h>
+#include <sys/stat.h>	/* for struct stat */
 #include <fcntl.h>
-#include <malloc.h>
+
 #include <assert.h>
 #include <ctype.h>
 #include <glib.h>
@@ -21,6 +25,27 @@
 #include <libole2/ms-ole.h>
 #include "config.h"
 
+#ifdef HAVE_MMAP
+#include <sys/mman.h>
+#endif
+
+#ifdef HAVE_UNISTD_H
+#	include <unistd.h>
+#else
+#	include <io.h>
+#	include <sys/stat.h>
+#	include <sys/types.h>
+/*
+#	define S_IRUSR 0000400
+#	define S_IWUSR 0000200
+#	define S_IRGRP 0000040
+#	define S_IWGRP 0000020
+#	define _S_ISREG(m) (((m)&0170000) == 0100000)
+#	define S_ISREG(m) _S_ISREG(m)
+#	define O_NONBLOCK 0x4000
+*/
+#endif
+
 #ifndef MAP_FAILED
 /* Someone needs their head examining - BSD ? */
 #	define MAP_FAILED ((void *)-1)
@@ -499,7 +524,7 @@ dump_tree (GList *list, int indent)
 	while (list) {
 		p = list->data;
 		if (p) {
-			printf ("%s '%s' - %d\n",
+		       printf ("%s '%s' (size: %d)\n",
 				indentstr, p->name, p->size);
 			if (p->children)
 				dump_tree (p->children, indent+1);
@@ -914,6 +939,9 @@ get_pps_ptr (MsOle *f, PPS_IDX i, gboolean forwrite)
 		return 0;
 	}
 
+#if OLE_DEBUG > 0
+	printf ("get_pps_ptr: blk = %d\n", blk);
+#endif
 	if (forwrite)
 		return BB_W_PTR(f, blk) + (i%(BB_BLOCK_SIZE/PPS_BLOCK_SIZE))*PPS_BLOCK_SIZE;
 	else
@@ -948,6 +976,9 @@ pps_decode_tree (MsOle *f, PPS_IDX p, PPS *parent)
 		f->pps = NULL;
 		return;
 	}
+#if OLE_DEBUG > 0
+	printf ("pps_decode_tree: mem (offset)= %#8.8x\n", mem - f->mem);
+#endif
 	pps->name     = pps_get_text  (mem, PPS_GET_NAME_LEN(mem));
 	pps->type     = PPS_GET_TYPE  (mem);
 	pps->size     = PPS_GET_SIZE  (mem);
@@ -1492,7 +1523,9 @@ MsOleErr
 ms_ole_open_vfs (MsOle **f, const char *name, gboolean try_mmap,
 		 MsOleSysWrappers *wrappers)
 {
+#ifdef HAVE_MMAP
 	int prot = PROT_READ | PROT_WRITE;
+#endif
 	int file;
 
 	if (!f)
@@ -2103,6 +2136,7 @@ ms_ole_read_copy_bb (MsOleStream *s, guint8 *ptr, MsOlePos length)
 	g_return_val_if_fail (s, 0);
 	g_return_val_if_fail (ptr, 0);
 
+	
 	if (!s->blocks) {
 		printf ("Reading from NULL file\n");
 		return 0;
@@ -2159,6 +2193,7 @@ ms_ole_read_copy_sb (MsOleStream *s, guint8 *ptr, MsOlePos length)
 	g_return_val_if_fail (s, 0);
 	g_return_val_if_fail (ptr, 0);
 
+	
 	if (!s->blocks) {
 		printf ("Reading from NULL file\n");
 		return 0;
@@ -2181,7 +2216,7 @@ ms_ole_read_copy_sb (MsOleStream *s, guint8 *ptr, MsOlePos length)
 		g_assert (blkidx < s->blocks->len);
 		block = ms_array_index (s->blocks, BLP, blkidx);
 		src = GET_SB_R_PTR(s->file, block) + offset;
-				
+		
 		memcpy (ptr, src, cpylen);
 		ptr += cpylen;
 		length -= cpylen;
